@@ -3,6 +3,7 @@ from pythautomata.base_types.alphabet import Alphabet
 from pythautomata.automata.wheighted_automaton_definition.probabilistic_deterministic_finite_automaton import \
      ProbabilisticDeterministicFiniteAutomaton
 from pythautomata.automata.wheighted_automaton_definition.weighted_state import WeightedState
+from pythautomata.model_comparators.wfa_comparison_strategy import WFAComparator
 
 binaryAlphabet = Alphabet(frozenset((SymbolStr('0'), SymbolStr('1'))))
 zero = binaryAlphabet['0']
@@ -23,28 +24,28 @@ class WeightedTomitasGrammars:
 
     Methods
     -------   
-    get_all_automata: list(WeightedAutomaton)
+    get_all_automata: list(ProbabilisticDeterministicFiniteAutomaton)
         returns a list containing all weigthed automata defined in this class
 
-    get_automaton_1: WeightedAutomaton
+    get_automaton_1: ProbabilisticDeterministicFiniteAutomaton
         returns the weighted automaton 1 from the paper
     
-    get_automaton_2: WeightedAutomaton
+    get_automaton_2: ProbabilisticDeterministicFiniteAutomaton
         returns the weighted automaton 2 from the paper
 
-    get_automaton_3: WeightedAutomaton
+    get_automaton_3: ProbabilisticDeterministicFiniteAutomaton
         returns the weighted automaton 3 from the paper
 
-    get_automaton_4: WeightedAutomaton
+    get_automaton_4: ProbabilisticDeterministicFiniteAutomaton
         returns the weighted automaton 4 from the paper
 
-    get_automaton_5: WeightedAutomaton
+    get_automaton_5: ProbabilisticDeterministicFiniteAutomaton
         returns the weighted automaton 5 from the paper
 
-    get_automaton_6: WeightedAutomaton
+    get_automaton_6: ProbabilisticDeterministicFiniteAutomaton
         returns the weighted automaton 6 from the paper
 
-    get_automaton_7: WeightedAutomaton
+    get_automaton_7: ProbabilisticDeterministicFiniteAutomaton
         returns the weighted automaton 7 from the paper
     """
 
@@ -55,7 +56,7 @@ class WeightedTomitasGrammars:
 
         Returns
         -------
-        list(WeightedAutomaton)
+        list(ProbabilisticDeterministicFiniteAutomaton)
             all automata defined in the class
         """
         return [
@@ -75,7 +76,7 @@ class WeightedTomitasGrammars:
 
         Returns
         -------
-        WeightedAutomaton
+        ProbabilisticDeterministicFiniteAutomaton
             weighted tomita grammar 1
         """
         q0 = WeightedState("q0", 1, 0.05)
@@ -87,7 +88,8 @@ class WeightedTomitasGrammars:
         q1.add_transition(one, q1, 0.665)
 
         states = {q0, q1}
-        return ProbabilisticDeterministicFiniteAutomaton(binaryAlphabet, states, SymbolStr("$"), "WeightedTomitas1")
+        comparator = WFAComparator()
+        return ProbabilisticDeterministicFiniteAutomaton(binaryAlphabet, states, SymbolStr("$"), comparator, "WeightedTomitas1")
 
     @staticmethod
     def get_automaton_2():
@@ -96,7 +98,7 @@ class WeightedTomitasGrammars:
 
         Returns
         -------
-        WeightedAutomaton
+        ProbabilisticDeterministicFiniteAutomaton
             weighted tomita grammar 2
         """
         q0 = WeightedState("q0", 1, 0.05)
@@ -111,7 +113,8 @@ class WeightedTomitasGrammars:
         q2.add_transition(one, q2, 0.665)
 
         states = {q0, q1, q2}
-        return ProbabilisticDeterministicFiniteAutomaton(binaryAlphabet, states, SymbolStr("$"), "WeightedTomitas2")
+        comparator = WFAComparator()
+        return ProbabilisticDeterministicFiniteAutomaton(binaryAlphabet, states, SymbolStr("$"), comparator ,"WeightedTomitas2")
 
     @staticmethod
     def get_automaton_3():
@@ -120,7 +123,7 @@ class WeightedTomitasGrammars:
 
         Returns
         -------
-        WeightedAutomaton
+        ProbabilisticDeterministicFiniteAutomaton
             weighted tomita grammar 3
         """
         q0 = WeightedState("q0", 1, 0.05)
@@ -141,7 +144,8 @@ class WeightedTomitasGrammars:
         q4.add_transition(one, q4, 0.665)
 
         states = {q0, q1, q2, q3, q4}
-        return ProbabilisticDeterministicFiniteAutomaton(binaryAlphabet, states, SymbolStr("$"), "WeightedTomitas3")
+        comparator = WFAComparator()
+        return ProbabilisticDeterministicFiniteAutomaton(binaryAlphabet, states, SymbolStr("$"), comparator,"WeightedTomitas3")
 
     @staticmethod
     def get_automaton_4():
@@ -150,7 +154,7 @@ class WeightedTomitasGrammars:
 
         Returns
         -------
-        WeightedAutomaton
+        ProbabilisticDeterministicFiniteAutomaton
             weighted tomita grammar 4
         """
         q0 = WeightedState("q0", 1, 0.05)
@@ -168,7 +172,8 @@ class WeightedTomitasGrammars:
         q3.add_transition(one, q3, 0.665)
 
         states = {q0, q1, q2, q3}
-        return ProbabilisticDeterministicFiniteAutomaton(binaryAlphabet, states, SymbolStr("$"), "WeightedTomitas4")
+        comparator = WFAComparator()
+        return ProbabilisticDeterministicFiniteAutomaton(binaryAlphabet, states, SymbolStr("$"), comparator, "WeightedTomitas4")
 
     @staticmethod
     def get_automaton_5():
@@ -177,7 +182,7 @@ class WeightedTomitasGrammars:
 
         Returns
         -------
-        WeightedAutomaton
+        ProbabilisticDeterministicFiniteAutomaton
             weighted tomita grammar 5
         """
         q0 = WeightedState("q0", 1, 0.05)
@@ -195,7 +200,8 @@ class WeightedTomitasGrammars:
         q3.add_transition(one, q2, 0.665)
 
         states = {q0, q1, q2, q3}
-        return ProbabilisticDeterministicFiniteAutomaton(binaryAlphabet, states, SymbolStr("$"), "WeightedTomitas5")
+        comparator = WFAComparator()
+        return ProbabilisticDeterministicFiniteAutomaton(binaryAlphabet, states, SymbolStr("$"), comparator, "WeightedTomitas5")
 
     @staticmethod
     def get_automaton_6():
@@ -204,7 +210,7 @@ class WeightedTomitasGrammars:
 
         Returns
         -------
-        WeightedAutomaton
+        ProbabilisticDeterministicFiniteAutomaton
             weighted tomita grammar 6
         """
         q0 = WeightedState("q0", 1, 0.05)
@@ -219,7 +225,8 @@ class WeightedTomitasGrammars:
         q2.add_transition(one, q0, 0.665)
 
         states = {q0, q1, q2}
-        return ProbabilisticDeterministicFiniteAutomaton(binaryAlphabet, states, SymbolStr("$"), "WeightedTomitas6")
+        comparator = WFAComparator()
+        return ProbabilisticDeterministicFiniteAutomaton(binaryAlphabet, states, SymbolStr("$"), comparator, "WeightedTomitas6")
 
     @staticmethod
     def get_automaton_7():
@@ -228,7 +235,7 @@ class WeightedTomitasGrammars:
 
         Returns
         -------
-        WeightedAutomaton
+        ProbabilisticDeterministicFiniteAutomaton
             weighted tomita grammar 7
         """
         q0 = WeightedState("q0", 1, 0.05)
@@ -249,4 +256,5 @@ class WeightedTomitasGrammars:
         q4.add_transition(one, q4, 0.665)
 
         states = {q0, q1, q2, q3, q4}
-        return ProbabilisticDeterministicFiniteAutomaton(binaryAlphabet, states, SymbolStr("$"), "WeightedTomitas7")
\ No newline at end of file
+        comparator = WFAComparator()
+        return ProbabilisticDeterministicFiniteAutomaton(binaryAlphabet, states, SymbolStr("$"), comparator, "WeightedTomitas7")
\ No newline at end of file
